
# django-peeringdb

[![PyPI](https://img.shields.io/pypi/v/django_peeringdb.svg?maxAge=2592000)](https://pypi.python.org/pypi/django_peeringdb)
[![Travis CI](https://img.shields.io/travis/peeringdb/django-peeringdb.svg?maxAge=2592000)](https://travis-ci.org/peeringdb/django-peeringdb)
[![Code Health](https://landscape.io/github/peeringdb/django-peeringdb/master/landscape.svg?style=flat)](https://landscape.io/github/peeringdb/django-peeringdb/master)
[![Codecov](https://img.shields.io/codecov/c/github/peeringdb/django-peeringdb/master.svg?maxAge=2592000)](https://codecov.io/github/peeringdb/django-peeringdb)
[![Requires.io](https://img.shields.io/requires/github/peeringdb/django-peeringdb.svg?maxAge=2592000)](https://requires.io/github/peeringdb/django-peeringdb/requirements)

PeeringDB models and local synchronization for Django

See the docs at http://peeringdb.github.io/django-peeringdb/

